﻿//==============================================================================
//
//	FormBorder1
//		Version 1.0
//		Copyright 2010, Luc Pattyn
//		http://www.Perceler.com
//
//==============================================================================
// this little app shows all different form borders
//==============================================================================
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;			// Process
using System.Drawing;
using System.IO;					// File
using System.Windows.Forms;

namespace FormBorder1 {
	public partial class Form1 : Form {
		private bool visualStyles;
		private List<Form> forms=new List<Form>();

		public Form1() : this(false) {}

		public Form1(bool visualStyles) {
			InitializeComponent();
			this.visualStyles=visualStyles;
			this.Width=650;
			this.Height=SystemInformation.PrimaryMonitorSize.Height-50;
			// initialize checkbox, only then wire the handler
			cbVisualStyles.Checked=visualStyles;
			cbVisualStyles.CheckedChanged+=cbVisualStyles_CheckedChanged;
		}

		private void Form1_Load(object sender, EventArgs e) {
			Text="FormBorder1 (PID="+Process.GetCurrentProcess().Id.ToString("X")+")";
			btnCreateAll.PerformClick();
		}


		private void btnRemove_Click(object sender, EventArgs e) {
			foreach (Form f in forms) {
				f.Hide();
				f.Dispose();
			}
			forms.Clear();
		}

		private void btnCreateAll_Click(object sender, EventArgs e) {
			btnRemove.PerformClick();
			for (int i=0; i<2; i++) {
				bool titleParts=i==0;
				int x=this.Left+50+i*300;
				int y=this.Top+100;
				y=addForm(FormBorderStyle.None, x, y, titleParts);
				y=addForm(FormBorderStyle.Fixed3D, x, y, titleParts);
				y=addForm(FormBorderStyle.FixedDialog, x, y, titleParts);
				y=addForm(FormBorderStyle.FixedSingle, x, y, titleParts);
				y=addForm(FormBorderStyle.FixedToolWindow, x, y, titleParts);
				y=addForm(FormBorderStyle.Sizable, x, y, titleParts);
				y=addForm(FormBorderStyle.SizableToolWindow, x, y, titleParts);
			}
		}

		private int addForm(FormBorderStyle borderStyle, int x, int y, bool titleParts) {
			Form f=new Form();
			f.FormBorderStyle=borderStyle;
			f.MinimizeBox=titleParts;
			f.MaximizeBox=titleParts;
			f.ControlBox=titleParts;
			if (titleParts) f.Text="Title";
			f.StartPosition=FormStartPosition.Manual;
			f.Bounds=new Rectangle(x, y, 250, 80);
			f.Owner=this;
			f.BackColor=Color.Khaki;
			Label lbl=new Label();
			string s=borderStyle.ToString()+"  (VS="+visualStyles+")";
			lbl.Text=s;
			lbl.Bounds=new Rectangle(50, 20, 200, 30);
			f.Controls.Add(lbl);
			f.ShowInTaskbar=false;
			f.Show();
			forms.Add(f);
			return y+100;
		}

		private void cbVisualStyles_CheckedChanged(object sender, EventArgs e) {
			visualStyles=cbVisualStyles.Checked;
			try {
				File.WriteAllText(Program.FILE, visualStyles?"1":"0");
			} catch (Exception exc) {
				MessageBox.Show(exc.ToString());
			}
			Application.Restart();
		}
	}
}
